<?php
/**
 * The plugin Elementor addons Initializer.
 *
 * @link       https://shapedplugin.com/
 * @since      3.0.0
 *
 * @package    location_weather
 * @subpackage location_weather/Admin
 * @author     ShapedPlugin <support@shapedplugin.com>
 */

namespace ShapedPlugin\Weather\Admin\ElementBlock;

use ShapedPlugin\Weather\Frontend\Shortcode;

/**
 * Elementor Location Weather shortcode Widget.
 *
 * @since 2.2.5
 */
class Location_Weather_Shortcode_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * @since 2.2.5
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'location_weather_shortcode';
	}

	/**
	 * Get widget title.
	 *
	 * @since 2.2.5
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Location Weather', 'location-weather' );
	}

	/**
	 * Get widget icon.
	 *
	 * @since 2.2.5
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'icon-lw-icon';
	}

	/**
	 * Get widget categories.
	 *
	 * @since 2.2.5
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'basic' );
	}

	/**
	 * Get all post list.
	 *
	 * @since 2.2.5
	 * @return array
	 */
	public function sptp_post_list() {
		$post_list  = array();
		$splw_posts = new \WP_Query(
			array(
				'post_type'      => 'location_weather',
				'post_status'    => 'publish',
				'posts_per_page' => 10000,
			)
		);
		$posts      = $splw_posts->posts;
		foreach ( $posts as $post ) {
			$post_list[ $post->ID ] = $post->post_title;
		}
		krsort( $post_list );
		return $post_list;
	}

	/**
	 * Controls register.
	 *
	 * @return void
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'content_section',
			array(
				'label' => __( 'Content', 'location-weather' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			)
		);

		$this->add_control(
			'sp_location_weather_pro_shortcode',
			array(
				'label'       => __( 'Location Weather Shortcode(s)', 'location-weather' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'label_block' => true,
				'default'     => '',
				'options'     => $this->sptp_post_list(),
			)
		);

		$this->end_controls_section();

	}

	/**
	 * Render team pro shortcode widget output on the frontend.
	 *
	 * @since 2.2.5
	 * @access protected
	 */
	protected function render() {

		$settings       = $this->get_settings_for_display();
		$splw_shortcode = $settings['sp_location_weather_pro_shortcode'];

		if ( '' === $splw_shortcode ) {
			echo '<div style="text-align: center; margin-top: 0; padding: 10px" class="elementor-add-section-drag-title">Select a shortcode</div>';
			return;
		}

		$shortcode_id = $splw_shortcode;

		if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
			$splw_option = get_option( 'location_weather_settings', true );
			$splw_meta   = get_post_meta( $shortcode_id, 'sp_location_weather_generator', true );
			// Stylesheet loading problem solving here. Shortcode id to push page id option for getting how many shortcode in the page.
			$current_page_id    = get_queried_object_id();
			$option_key         = 'sp_lw_page_id' . $current_page_id;
			$found_generator_id = get_option( $option_key );
			if ( is_multisite() ) {
				$option_key         = 'sp_lw_page_id' . get_current_blog_id() . $current_page_id;
				$found_generator_id = get_site_option( $option_key );
			}
			// This shortcode id not in page id option. Enqueue stylesheets in shortcode.
			if ( ! is_array( $found_generator_id ) || ! $found_generator_id || ! in_array( $shortcode_id, $found_generator_id ) ) {
				$splw_id    = $shortcode_id;
				$custom_css = '';
				wp_enqueue_style( 'splw-styles' );
				wp_enqueue_style( 'splw-old-styles' );
				include LOCATION_WEATHER_PATH . '/includes/Frontend/dynamic-style.php';
				echo '<style id="sp_lw_dynamic_css' . $splw_id . '">' . $custom_css . '</style>';
			}

			if ( $found_generator_id ) {
				$found_generator_id = is_array( $found_generator_id ) ? $found_generator_id : array( $found_generator_id );
				if ( ! in_array( $shortcode_id, $found_generator_id ) || empty( $found_generator_id ) ) {
					// If not found the shortcode id in the page options.
					array_push( $found_generator_id, $shortcode_id );
					if ( is_multisite() ) {
						update_site_option( $option_key, $found_generator_id );
					} else {
						update_option( $option_key, $found_generator_id );
					}
				}
			} else {
				// If option not set in current page add option.
				if ( $current_page_id ) {
					if ( is_multisite() ) {
						add_site_option( $option_key, array( $shortcode_id ) );
					} else {
						add_option( $option_key, array( $shortcode_id ) );
					}
				}
			}
			Shortcode::splw_html_show( $shortcode_id, $splw_option, $splw_meta );
			?>
			<?php
		} else {
			echo do_shortcode( '[location-weather id="' . $shortcode_id . '"]' );
		}

	}

}
