<?php
/**
 * Script class file.
 *
 * @package Location_Weather
 */

namespace ShapedPlugin\Weather\Frontend;

use ShapedPlugin\Weather\Frontend;

/**
 * Script class used to hold the style and script for frontend.
 */
class Scripts {

	/**
	 * Script and style suffix
	 *
	 * @var string
	 */
	protected $suffix;

	/**
	 * The constructor of the class.
	 */
	public function __construct() {
			$this->scripts_handler();
	}

	/**
	 * Frontend script handler.
	 *
	 * @return void
	 */
	public function scripts_handler() {
		add_action( 'wp_enqueue_scripts', array( $this, 'lw_styles' ) );
	}

	/**
	 * Register the scripts for the public-facing side of the site.
	 *
	 * @since    2.0.0
	 */
	public function lw_styles() {
		// Stylesheet loading problem solving here. Shortcode id to push page id option for getting how many shortcode in the page.
		$current_page_id    = get_queried_object_id();
		$option_key         = 'sp_lw_page_id' . $current_page_id;
		$found_generator_id = get_option( $option_key );
		if ( is_multisite() ) {
			$option_key         = 'sp_lw_page_id' . get_current_blog_id() . $current_page_id;
			$found_generator_id = get_site_option( $option_key );
		}

		/**
		 * This function is provided for demonstration purposes only.
		 */
		if ( $found_generator_id ) {
			wp_enqueue_style( 'splw-styles' );
			wp_enqueue_style( 'splw-old-styles' );

			wp_enqueue_script( 'splw-old-script' );

			$custom_css      = '';
			$setting_options = get_option( 'location_weather_settings', true );
			$splw_custom_css = $setting_options['splw_custom_css'];
			foreach ( $found_generator_id as $splw_id ) {
				if ( $splw_id && is_numeric( $splw_id ) && get_post_status( $splw_id ) !== 'trash' ) {
					$splw_option = get_option( $splw_id, 'location_weather_settings', true );
					$splw_meta   = get_post_meta( $splw_id, 'sp_location_weather_generator', true );
					include LOCATION_WEATHER_PATH . '/includes/Frontend/dynamic-style.php';
				}
			}
			if ( ! empty( $splw_custom_css ) ) {
				$custom_css .= $splw_custom_css;
			}
			$custom_css = Frontend::minify_output( $custom_css );
			// Add dynamic style.
			wp_add_inline_style( 'splw-styles', $custom_css );
		}
	}
}
